package com.ruoyi.ems.base.service;

import java.util.List;

import com.ruoyi.ems.base.domain.EmsBaseSharePrice;

/**
 * 分时电价维护Service接口
 *
 * @author Yinq
 * @date 2024-06-11
 */
public interface IEmsBaseSharePriceService {
    /**
     * 查询分时电价维护
     *
     * @param objId 分时电价维护主键
     * @return 分时电价维护
     */
    public EmsBaseSharePrice selectEmsBaseSharePriceByObjId(Long objId);

    /**
     * 查询分时电价维护列表
     *
     * @param emsBaseSharePrice 分时电价维护
     * @return 分时电价维护集合
     */
    public List<EmsBaseSharePrice> selectEmsBaseSharePriceList(EmsBaseSharePrice emsBaseSharePrice);

    /**
     * 新增分时电价维护
     *
     * @param emsBaseSharePrice 分时电价维护
     * @return 结果
     */
    public int insertEmsBaseSharePrice(EmsBaseSharePrice emsBaseSharePrice);

    /**
     * 修改分时电价维护
     *
     * @param emsBaseSharePrice 分时电价维护
     * @return 结果
     */
    public int updateEmsBaseSharePrice(EmsBaseSharePrice emsBaseSharePrice);

    /**
     * 批量删除分时电价维护
     *
     * @param objIds 需要删除的分时电价维护主键集合
     * @return 结果
     */
    public int deleteEmsBaseSharePriceByObjIds(Long[] objIds);

    /**
     * 删除分时电价维护信息
     *
     * @param objId 分时电价维护主键
     * @return 结果
     */
    public int deleteEmsBaseSharePriceByObjId(Long objId);
}
